@@ -144,7 +144,7 @@ async def _wait_future(id: int, timeout: float, store: MetaStore) -> Update:
     await store.set_item(id, fn)
 
     try:
-        return await asyncio.wait_for(fn, timeout, loop=loop)
+        return await asyncio.wait_for(fn, timeout)
     finally:
         await unregister_steps(id, store)
 
